@@ -37,26 +37,22 @@ class AttendeeLineEditDelegate : public QStyledItemDelegate
 public:
     explicit AttendeeLineEditDelegate(QObject *parent = nullptr);
 
-    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-                          const QModelIndex &index) const override;
+    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     void setEditorData(QWidget *editor, const QModelIndex &index) const override;
-    void setModelData(QWidget *editor, QAbstractItemModel *model,
-                      const QModelIndex &index) const override;
-    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option,
-                              const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+    void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     virtual void setCompletionMode(KCompletion::CompletionMode mode);
 
 public Q_SLOTS:
-    bool helpEvent(QHelpEvent *event, QAbstractItemView *view, const QStyleOptionViewItem &option,
-                   const QModelIndex &index) override;
+    bool helpEvent(QHelpEvent *event, QAbstractItemView *view, const QStyleOptionViewItem &option, const QModelIndex &index) override;
 
 private:
     void rightPressed();
     void leftPressed();
     QString mToolTip;
     QString mWhatsThis;
-    KCompletion::CompletionMode mCompletionMode;
+    KCompletion::CompletionMode mCompletionMode = KCompletion::CompletionPopup;
 };
 }
 
