@@ -225,9 +225,9 @@ VisualFreeBusyWidget::VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *m
     mLeftView->setHeader(new GanttHeaderView);
     mLeftView->header()->setStretchLastSection(true);
     mLeftView->setToolTip(i18nc("@info:tooltip",
-              "Shows the tree list of all data"));
+                                "Shows the tree list of all data"));
     mLeftView->setWhatsThis(i18nc("@info:whatsthis",
-              "Shows the tree list of all data"));
+                                  "Shows the tree list of all data"));
     mLeftView->setRootIsDecorated(false);
     mLeftView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     mLeftView->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -267,8 +267,13 @@ VisualFreeBusyWidget::VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *m
 
     // Initially, show 15 days back and forth
     // set start to even hours, i.e. to 12:AM 0 Min 0 Sec
-    QDateTime horizonStart
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+    const QDateTime horizonStart
         = QDateTime(QDateTime::currentDateTime().addDays(-15).date());
+#else
+    const QDateTime horizonStart
+        = QDateTime(QDateTime::currentDateTime().addDays(-15).date().startOfDay());
+#endif
     mGanttGrid->setStartDateTime(horizonStart);
 
     connect(mLeftView, &QTreeView::customContextMenuRequested, this,
@@ -317,7 +322,13 @@ void VisualFreeBusyWidget::slotUpdateIncidenceStartEnd(const QDateTime &dtFrom,
 {
     mDtStart = dtFrom;
     mDtEnd = dtTo;
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QDateTime horizonStart = QDateTime(dtFrom.addDays(-15).date());
+#else
+    QDateTime horizonStart = QDateTime(dtFrom.addDays(-15).date().startOfDay());
+#endif
+
+
     KGantt::DateTimeGrid *grid = static_cast<KGantt::DateTimeGrid *>(mGanttGraphicsView->grid());
     grid->setStartDateTime(horizonStart);
     slotCenterOnStart();
